# telegram-messager


Simplest util to send messages to Telegram.

Usage:
```python
from telegram_messager import TelegramMessager

TM = TelegramMessager(token='token', chatid='chatid')
TM.send_msg('message')
```
